<?php

class ApiNexusErp {
	private $NameApp  = "API NexusErp";
	private $version  = NULL;
	private $ip 	  = NULL;
	private $port     = NULL;
	private $user  	  = NULL;
	private $password = NULL;
	private $api_key  = NULL;
	private $arrResult = array();
	
	function __construct() {
		$errors = array();
		$php_min_version = '5.5.19';
		$curl_min_version = '7.34.0';

		if (version_compare(phpversion(), $php_min_version, '<')) {
			$errors[] = '<b>Versiune PHP '.$php_min_version.'</b> utilizata de <b>'.$NameApp.'</b> kit. Versiune curenta de PHP: <b>'.phpversion().'!</b>';
		}

		if (!extension_loaded('curl')) {
			$errors[] = '<b>'.$NameApp.'</b> utlizeaza extensia cURL. Extensia cURL este <b>dezactivata!</b>';
		}

		if (version_compare(curl_version()['version'], $curl_min_version, '<')) {
			$errors[] = '<b>Versiune cURL '.$curl_min_version.'</b> utilizata de <b>'.$NameApp.'</b> kit. Versiune curenta de cURL: <b>'.curl_version()['version'].'!</b>';
		}

		if (isset($errors) && !empty($errors)) { 
			foreach ($errors as $error) {
				echo $error."<hr />";
			}
			die('Va rugam sa va actualizati setarile la site pentru a utiliza <b>'.$NameApp.'</b>!');
		}
	}
	
	public function ApiNexusErp() {
		$this->version = "v1";
	}	
	
	
	public function setPort($port) {
		$this->port = $port;
	}	

	public function setIp($ip) {
		$this->ip = $ip;
	}	

	public function setApiKey($api_key) {
		$this->api_key = $api_key;
	}	
	
	public function setApiUser($user) {
		$this->user = $user;
	}
	
	public function setApiPassword($password) {
		$this->password = $password;
	}	
	
	
	private function CheckIsJson($string) {
		$data = json_decode($string);
		return (json_last_error() === JSON_ERROR_NONE);
	}
	
	private function CheckData() { 
		if (empty($this->ip) || is_null($this->ip))  
		{
			return false;	
		}
		if (empty($this->port) || is_null($this->port))  
		{
			return false;	
		}
		
		if (empty($this->api_key) || is_null($this->api_key))  
		{
			return false;	
		}
		return true;
	}
	
	public function getArrResult()
	{
		return $this->arrResult;
	}	
	
	// citeste date din NEXUS ERP
	public function Read($tip_citire, $json_post) {
		$this->arrResult  = array();
		
		$tipuri_import =array(
								"adrese_parteneri",
								"atribute_produse",
								"clase_produse",
								"clasificari",
								"conturi_bunuri_servicii",
								"facturi_clienti",
								"fisier_arhiva",
								"generare_nir",
								"gestiuni",
								"grup_oferta",
								"grupe_produse",
								"membri_stare_actuala",
								"parteneri",
								"preturi",
								"promotii",
								"stoc",
								"subclase_produse",
								"magazin"
							);		
		
		if (!in_array($tip_citire, $tipuri_import)) {
			$this->arrResult = array("isError" => true,
							   "message" => "Tip citire date eronat!",
			                   "result" => "");
			return;			
		}
		
		if (!$this->CheckIsJson(json_encode($json_post))) {
			$this->arrResult = array("isError" => true,
							   "message" => "Parametru data format JSON eronat!",
			                   "result" => "");
			return;					
		}		
		
		try {
			$curl = curl_init();
			curl_setopt_array($curl, array(
											CURLOPT_PORT => $this->port,
											CURLOPT_URL => "http://".$this->ip.":".$this->port."/api/v1/read/".$tip_citire,
											CURLOPT_RETURNTRANSFER => true,
											CURLOPT_ENCODING => "",
											CURLOPT_MAXREDIRS => 10,
											CURLOPT_TIMEOUT => 30,
											CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
											CURLOPT_CUSTOMREQUEST => "POST",
											CURLOPT_POSTFIELDS => $json_post,
											CURLOPT_HTTPHEADER => array(
																		   "Authorization: Basic ".base64_encode($this->api_key.":") ."" ,
																		   "Cache-Control: no-cache",
																		   "Content-Type: application/json"
																		)
											)
								);

			$response = curl_exec($curl);
			$err = curl_error($curl);
			$info = curl_getinfo($curl);
			curl_close($curl);
			
			
			if ($err) {
				$this->arrResult = array("isError" => true,
							   "message" => $err,
			                   "result" => "");
			} 
			else 
			{		
				switch($info['http_code']) {
					case 200:  //"OK"
						$this->arrResult = json_decode($response, true);
						break;
					case 400: // "Bad Request"
						$this->arrResult = array("isError" => true,
												 "message" => "Cerere gresita (CODE 400)!",
												 "result" => "");					
						break; 	
					case 401: // "Unauthorized"
						$this->arrResult = array("isError" => true,
												 "message" => "Acces neautorizat (CODE 401)!",
												 "result" => "");					
						break; 	
					case 403: // "Forbidden"
						$this->arrResult = array("isError" => true,
												 "message" => "Acces neautorizat (CODE 403)!",
												 "result" => "");					
						break;	
					case 500: // "Internal Server Error" sau eroare din Serviciul nexus ERP 
						$mesaage_err = "Eroare interna server (CODE 500)!";
						$pos = strpos($response, '"isError":true');
						if ($pos === false) {
							//$mesaage_err = "Eroare interna server (CODE 500)!";
						} else {
							$info_err = json_decode($response, true);	
							if (is_array($info_err)) {
								if (array_key_exists("message", $info_err)) {
									$mesaage_err = $info_err["message"];
								}
							}
						}
						$this->arrResult = array("isError" => true,
												 "message" => $mesaage_err,
												 "result" => "");					
					
						break;
					default: 	
						$this->arrResult = array("isError" => true,
												 "message" => "Eroare acces serviciu Nexus API (CODE ".$info['http_code'].")!",
												 "result" => "");					
						break;
				}
			}			
		}
		catch (Exception $e) 
		{		
			$this->arrResult = array("isError" => true,
							   "message" => $e->getMessage(),
			                   "result" => "");
		}
	}
	
	// import date in NEXUS ERP
	public function Import($tip_import, $json_post) {
		$this->arrResult  = array();
		
		$tipuri_import =array(
								"adrese",
								"arhiva_produse",
								"avize_clienti",
								"avize_custodie_clienti",
								"bonuri_consum",
								"bonuri_consum_obiecte_inventar",
								"bonuri_fiscale",
								"bonuri_productie",
								"cant_lim",
								"cheltuieli_in_avans",
								"clase_produse",
								"comenzi_clienti",
								"crm_interventii",
								"delegati",
								"decizii_salarizare",
								"facturi_bonuri_fiscale",
								"facturi_clienti",
								"facturi_furnizori",
								"incasari_plati",
								"inventar",
								"modificare_pret_amanunt",
								"nomen4",
								"note_contabile_manuale",
								"note_intrare_receptie",
								"oferte_furnizori",
								"parteneri",
								"personal",
								"pontaje",
								"preturi_vanzare_produse",
								"produse",
								"pv_diferente_inventar",
								"pv_perisabilitati",
								"retete_productie",
								"retete_restaurant",
								"subclase_produse",
								"transferuri_produse",
								"venituri_in_avans",
								"rgpd_acorduri_primite",
								"rgpd_evidenta_prelucrari"
							);		
		
		if (!in_array($tip_import, $tipuri_import)) {
			$this->arrResult = array("isError" => true,
							   "message" => "Tip import eronat!",
			                   "result" => "");
			return;			
		}
		
		if (!$this->CheckData()) {
			$this->arrResult = array("isError" => true,
							   "message" => "Parametrii date eronati!",
			                   "result" => "");
			return;					
		}
		
		if (!$this->CheckIsJson(json_encode($json_post))) {
			$this->arrResult = array("isError" => true,
							   "message" => "Parametru data format JSON eronat!",
			                   "result" => "");
			return;					
		}		
		
		try {
			$curl = curl_init();
			curl_setopt_array($curl, array(
											CURLOPT_PORT => $this->port,
											CURLOPT_URL => "http://".$this->ip.":".$this->port."/api/v1/import/".$tip_import,
											CURLOPT_RETURNTRANSFER => true,
											CURLOPT_ENCODING => "",
											CURLOPT_MAXREDIRS => 10,
											CURLOPT_TIMEOUT => 30,
											CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
											CURLOPT_CUSTOMREQUEST => "POST",
											CURLOPT_POSTFIELDS => "{data:".$json_post."}",
											CURLOPT_HTTPHEADER => array(
																		   "Authorization: Basic ".base64_encode($this->api_key.":") ."" ,
																		   "Cache-Control: no-cache",
																		   "Content-Type: application/json"
																		),
											)
								);

			$response = curl_exec($curl);
			$err = curl_error($curl);
			$info = curl_getinfo($curl);
			curl_close($curl);
			
			if ($err) {
				$this->arrResult = array("isError" => true,
							             "message" => $err,
			                             "result" => "");
			} 
			else 
			{		
				switch($info['http_code']) {
					case 200:  //"OK"
						$this->arrResult = json_decode($response, true);
						break;
					case 400: // "Bad Request"
						$this->arrResult = array("isError" => true,
												 "message" => "Cerere gresita (CODE 400)!",
												 "result" => "");					
						break; 	
					case 401: // "Unauthorized"
						$this->arrResult = array("isError" => true,
												 "message" => "Acces neautorizat (CODE 401)!",
												 "result" => "");					
						break; 	
					case 403: // "Forbidden"
						$this->arrResult = array("isError" => true,
												 "message" => "Acces neautorizat (CODE 403)!",
												 "result" => "");					
						break;	
					case 500: // "Internal Server Error" sau eroare din Serviciul nexus ERP 
						$mesaage_err = "Eroare interna server (CODE 500)!";
						$pos = strpos($response, '"isError":true');
						if ($pos === false) {
							//$mesaage_err = "Eroare interna server (CODE 500)!";
						} else {
							$info_err = json_decode($response, true);	
							if (is_array($info_err)) {
								if (array_key_exists("message", $info_err)) {
									$mesaage_err = $info_err["message"];
								}
							}
						}
						$this->arrResult = array("isError" => true,
												 "message" => $mesaage_err,
												 "result" => "");					
					
						break;
					default: 	
						$this->arrResult = array("isError" => true,
												 "message" => "Eroare acces serviciu Nexus API (CODE ".$info['http_code'].")!",
												 "result" => "");					
						break;
				}
			}			
		}
		catch (Exception $e) 
		{		
			$this->arrResult = array("isError" => true,
							   "message" => $e->getMessage(),
			                   "result" => "");
		}
	}	
	
	public function IsOnline() {
		$this->arrResult  = array();
		
		try {
			$curl = curl_init();
			curl_setopt_array($curl, array(
											CURLOPT_PORT => $this->port,
											CURLOPT_URL => "http://".$this->ip.":".$this->port."/api/v1/ping",
											CURLOPT_RETURNTRANSFER => true,
											CURLOPT_ENCODING => "",
											CURLOPT_MAXREDIRS => 10,
											CURLOPT_TIMEOUT => 6,
											CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
											CURLOPT_CUSTOMREQUEST => "POST",
											CURLOPT_HTTPHEADER => array(
																		   "Authorization: Basic ".base64_encode($this->api_key.":") ."" ,
																		   "Cache-Control: no-cache",
																		   "Content-Type: text/plain",
																		   "Content-Length: 0"
																		),
											)
								);

			$response = curl_exec($curl);
			$err = curl_error($curl);
			$info = curl_getinfo($curl);
			curl_close($curl);
			
			if ($err) {
				$this->arrResult = array("isError" => true, "message" => $err);
			} 
			else 
			{		
				switch($info['http_code']) {
					case 200:  //"OK"
						$arr_return = json_decode($response, true);
						if (!is_array($arr_return)) {
							$this->arrResult = array("isError" => true, "message" => "Date return serviciu incorecte!");				
						}  elseif(!array_key_exists("isError", $arr_return) || !array_key_exists("message", $arr_return) || !array_key_exists("message", $arr_return)) {
							$this->arrResult = array("isError" => true, "message" => "Date return serviciu API incorecte!");				
						} else {
							$isError = $arr_return["isError"];
							$message = $arr_return["message"];
							if (!$isError && $message=="Test API OK") {
								$this->arrResult = array("isError" => false, "message" => "Test API OK");				
							} else {
								$this->arrResult = array("isError" => false, "message" => $message);				
							}
						}
						break;
					case 400: // "Bad Request"
						$this->arrResult = array("isError" => true, "message" => "Cerere gresita (CODE 400)!");					
						break; 	
					case 401: // "Unauthorized"
						$this->arrResult = array("isError" => true, "message" => "Acces neautorizat (CODE 401)!");					
						break; 	
					case 403: // "Forbidden"
						$this->arrResult = array("isError" => true, "message" => "Acces neautorizat (CODE 403)!");					
						break;	
					case 500: // "Internal Server Error" sau eroare din Serviciul nexus ERP 
						$mesaage_err = "Eroare interna server (CODE 500)!";
						$pos = strpos($response, '"isError":true');
						if ($pos === false) {
							//$mesaage_err = "Eroare interna server (CODE 500)!";
						} else {
							$info_err = json_decode($response, true);	
							if (is_array($info_err)) {
								if (array_key_exists("message", $info_err)) {
									$mesaage_err = $info_err["message"];
								}
							}
						}
						$this->arrResult = array("isError" => true,
												 "message" => $mesaage_err,
												 "result" => "");					
						break;
					default: 	
						$this->arrResult = array("isError" => true, "message" => "Eroare acces serviciu Nexus API (CODE ".$info['http_code'].")!");					
						break;
				}
			}			
		}
		catch (Exception $e) 
		{		
			$this->arrResult = array("isError" => true, "message" => $e->getMessage());
		}
	}		
}
?>